==> nm-tray_0.5.0.orig.tar.gz: nm-tray-0.5.0/translations/nm-tray_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Informații despre conexiune</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Toate informațiile</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Conexiuni active</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Conexiuni wireless disponibile</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray - parolă wireless</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="57"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Parola este necesară pentru conectarea la &apos;%1&apos;:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="745"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="747"/>
        <source>active connection(s)</source>
        <translation>conexiune (conexiuni) activă(e)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="749"/>
        <source>connection(s)</source>
        <translation>conexiune (conexiuni)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="751"/>
        <source>device(s)</source>
        <translation>dispozitiv(e)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="753"/>
        <source>wifi network(s)</source>
        <translation>rețea (rețele) wifi</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1044"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>Necunoscut</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1153"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Interfață</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1155"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Adresa hardware</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1157"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Driver</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1159"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Viteză</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1163"/>
        <source>Kb/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1165"/>
        <source>Mb/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1167"/>
        <source>Gb/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1169"/>
        <source>Tb/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Kb/s</source>
        <translation type="vanished"> Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1172"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>necunoscut</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1176"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Securitate</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1180"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1181"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1192"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>Adresă IP</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1194"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Mască de subrețea</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1203"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Rută implicită</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1209"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation>DNS(%1)</translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt; Conexiune &lt;strong&gt;%1&lt;/strong&gt;(%2) activă&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt; Nicio conexiune activă &lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Conexiune pierdută</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Nu mai este conectat la% 1 &apos;% 2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Conexiune stabilită</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Acum conectat la %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation>NetworkManager(nm-tray)</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Activați rețeaua</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Activați Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Activați notificările</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Informații despre conexiune</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Informații de depanare</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>Wifi - cereți scanare</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Editați conexiunile ...</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Ieșiți</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>informații nm-tray</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>%1 despre</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt; &lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; este un simplu frontend bazat pe Qt pentru &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;. &lt;br/&gt; &lt;br/&gt; Versiune: %1</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Conexiuni active</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>Rețea (rețele) Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Conexiuni cunoscute</translation>
    </message>
</context>
</TS>

==> nm-tray_0.5.1.orig.tar.gz: nm-tray-0.5.1/translations/nm-tray_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Informații despre conexiune</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Toate informațiile</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Conexiuni active</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Rețele fără fir disponibile</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray - parolă rețea fără fir</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="57"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Parola este necesară pentru conectarea la „%1”:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="745"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="747"/>
        <source>active connection(s)</source>
        <translation>conexiuni active</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="749"/>
        <source>connection(s)</source>
        <translation>conexiuni</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="751"/>
        <source>device(s)</source>
        <translation>dispozitiv(e)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="753"/>
        <source>wifi network(s)</source>
        <translation>rețele wifi</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1044"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>necunoscută</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1153"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Interfață</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1155"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Adresa hardware</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1157"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Controlor</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1159"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Viteză</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1163"/>
        <source>Kb/s</source>
        <translation>Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1165"/>
        <source>Mb/s</source>
        <translation>Mb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1167"/>
        <source>Gb/s</source>
        <translation>Gb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1169"/>
        <source>Tb/s</source>
        <translation>Tb/s</translation>
    </message>
    <message>
        <source> Kb/s</source>
        <translation type="vanished"> Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1172"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>necunoscută</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1176"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Securitate</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1180"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1181"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1192"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>Adresă IP</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1194"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Mască de subrețea</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1203"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Rută implicită</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1209"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation>DNS(%1)</translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt; Conexiune &lt;strong&gt;%1&lt;/strong&gt;(%2) activă&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt; Nicio conexiune activă &lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Conexiune pierdută</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Nu mai este conectat la% 1 „% 2”.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Conexiune stabilită</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Conectat la %1 „%2”.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation>NetworkManager(nm-tray)</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Activați rețeaua</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Activați Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Activați notificările</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Informații despre conexiune</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Informații de depanare</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>Wifi - cereți scanare</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Editați conexiunile ...</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Ieșiți</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>informații nm-tray</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>Despre %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt; &lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; este o simplă interfață bazată pe Qt pentru &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;. &lt;br/&gt; &lt;br/&gt; Versiune: %1</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Conexiuni active</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>Rețele Wi-Fi</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Conexiuni cunoscute</translation>
    </message>
</context>
</TS>
